@@ -15,6 +15,8 @@ import invoke
 import requests
 from urllib3.util import parse_url as urllib3_parse
 
+from pipenv.vendor.requirementslib.fileutils import open_file
+
 TASK_NAME = "update"
 
 LIBRARY_DIRNAMES = {
@@ -58,8 +60,9 @@ LIBRARY_RENAMES = {
     "pip": "pipenv.patched.pip",
     "requests": "pipenv.patched.pip._vendor.requests",
     "packaging": "pipenv.patched.pip._vendor.packaging",
-    "pep517": "pipenv.patched.pip._vendor.pep517",
+    # "pep517": "pipenv.patched.pip._vendor.pep517",
     "pkg_resources": "pipenv.patched.pip._vendor.pkg_resources",
+    "pyparsing": "pipenv.patched.pip._vendor.pyparsing",
     "ruamel.yaml": "pipenv.vendor.ruamel.yaml",
     "urllib3": "pipenv.patched.pip._vendor.urllib3",
 }
@@ -70,16 +73,17 @@ GLOBAL_REPLACEMENT = [
     (r"(?<!\.)\bpippipenv\.patched\.notpip", r"pipenv.patched.pip"),
     (
         r"(?<!\.)import pep517\.envbuild",
-        r"from pipenv.patched.pip._vendor.pep517 import envbuild",
+        r"from pipenv.vendor.pep517 import envbuild",
     ),
     (
         r"(?<!\.)import pep517\.wrappers",
-        r"from pipenv.patched.pip._vendor.pep517 import wrappers",
+        r"from pipenv.vendor.pep517 import wrappers",
     ),
     (
         r"from cached_property import cached_property",
-        r"from pipenv.vendor.pyparsing.core import cached_property",
+        r"from pipenv.patched.pip._vendor.pyparsing.core import cached_property",
     ),
+    (r"from pyparsing import", r"from pipenv.patched.pip._vendor.pyparsing import"),
     (r"(?<!\.)pep517\.envbuild", r"envbuild"),
     (r"(?<!\.)pep517\.wrappers", r"wrappers"),
     (r" ruamel\.yaml", r" ruamel"),
@@ -88,11 +92,20 @@ GLOBAL_REPLACEMENT = [
         "from pipenv.patched.pip._vendor.platformdirs import user_cache_dir",
     ),
     ("from distlib import", "from pipenv.patched.pip._vendor.distlib import"),
+    ("    import tomli", "    from pipenv.patched.pip._vendor import tomli"),
     (
         "from distlib.metadata import",
         "from pipenv.patched.pip._vendor.distlib.metadata import",
     ),
     ("from distlib.wheel import", "from pipenv.patched.pip._vendor.distlib.wheel import"),
+    (
+        "from typing_extensions import",
+        "from pipenv.patched.pip._vendor.typing_extensions import",
+    ),
+    (
+        "from pipenv.patched.pip._vendor.typing_extensions",
+        "from pipenv.patched.pip._vendor.typing_extensions",
+    ),
 ]
 
 
@@ -200,13 +213,13 @@ def rewrite_file_imports(item, vendored_libs):
 
     for lib, to_lib in vendored_libs.items():
         text = re.sub(
-            r"^(?m)(\s*)import %s((?:\.\S*)?\s+as)" % lib,
+            r"(?m)^(\s*)import %s((?:\.\S*)?\s+as)" % lib,
             r"\1import %s\2" % to_lib,
             text,
         )
-        text = re.sub(r"^(?m)(\s*)from %s([\s\.]+)" % lib, r"\1from %s\2" % to_lib, text)
+        text = re.sub(r"(?m)^(\s*)from %s([\s\.]+)" % lib, r"\1from %s\2" % to_lib, text)
         text = re.sub(
-            r"^(?m)(\s*)import %s(\s*[,\n#])" % lib,
+            r"(?m)^(\s*)import %s(\s*[,\n#])" % lib,
             r"\1import %s as %s\2" % (to_lib, lib),
             text,
         )
@@ -325,11 +338,6 @@ def post_install_cleanup(ctx, vendor_dir):
     drop_dir(vendor_dir / "colorama" / "tests")
 
     remove_all(vendor_dir.glob("toml.py"))
-    # this function is called twice hence try ... except ...
-    try:
-        (vendor_dir / "vistir" / "spin.py").unlink()
-    except FileNotFoundError:
-        pass
 
 
 @invoke.task
@@ -514,7 +522,6 @@ def download_licenses(
             ctx.run(exe_cmd)
         except invoke.exceptions.UnexpectedExit as e:
             if "ModuleNotFoundErr" in e.result.stderr.strip():
-
                 target = parse.parse(
                     "ModuleNotFoundError: No module named '{backend}'",
                     e.result.stderr.strip().split("\n")[-1],
@@ -768,8 +775,6 @@ def main(ctx, package=None, type=None):
 
 @invoke.task
 def vendor_artifact(ctx, package, version=None):
-    from pipenv.vendor.vistir.contextmanagers import open_file
-
     simple = requests.get(f"https://pypi.org/simple/{package}/")
     pkg_str = f"{package}-{version}"
     soup = bs4.BeautifulSoup(simple.content)
